@@ -33,6 +33,21 @@ test_that("Returns the correct number of predictors.", {
   expect_equal(ncol(simulate_gamma(weights = 1:4)), 5)
 })
 
+test_that("Returns the correct range for x.", {
+  expect_true(max(simulate_gamma(weights = 1, xrange = 0)[, 2]) <= 1)
+  expect_true(min(simulate_gamma(weights = 1, xrange = 0)[, 2]) >= 1)
+  expect_true(max(simulate_gamma(weights = 1, xrange = 2)[, 2]) <= 3)
+  expect_true(min(simulate_gamma(weights = 1, xrange = 2)[, 2]) >= 1)
+  expect_true(max(simulate_gamma(weights = 1, xrange = 3)[, 2]) <= 4)
+  expect_true(min(simulate_gamma(weights = 1, xrange = 3)[, 2]) >= 1)
+  expect_true(max(simulate_gamma(weights = c(1, 2), xrange = 0)[, 3]) <= 1)
+  expect_true(min(simulate_gamma(weights = c(1, 2), xrange = 0)[, 3]) >= 1)
+  expect_true(max(simulate_gamma(weights = c(1, 2), xrange = 2)[, 3]) <= 3)
+  expect_true(min(simulate_gamma(weights = c(1, 2), xrange = 2)[, 3]) >= 1)
+  expect_true(max(simulate_gamma(weights = c(1, 2), xrange = 3)[, 3]) <= 4)
+  expect_true(min(simulate_gamma(weights = c(1, 2), xrange = 3)[, 3]) >= 1)
+})
+
 test_that("Returns the correct number of unrelated variables.", {
   expect_equal(ncol(simulate_gamma(weights = 1, unrelated = 0)), 2)
   expect_equal(ncol(simulate_gamma(weights = 1, unrelated = 1)), 3)
@@ -63,6 +78,10 @@ test_that("Confirm input checing works.", {
   expect_error(simulate_gamma(N = c(100, 200)), NULL)
   expect_error(simulate_gamma(link = "sqrt"), NULL)
   expect_error(simulate_gamma(weights = c()), NULL)
+  expect_error(simulate_gamma(xrange = "asdf"), NULL)
+  expect_error(simulate_gamma(xrange = c()), NULL)
+  expect_error(simulate_gamma(xrange = c(1, 2)), NULL)
+  expect_error(simulate_gamma(xrange = -1), NULL)
   expect_error(simulate_gamma(unrelated = -1), NULL)
   expect_error(simulate_gamma(unrelated = c(10, 20)), NULL)
   expect_error(simulate_gamma(ancillary = -1), NULL)
